/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLButtonElement.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLButtonElement.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLButtonElement.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLButtonElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLButtonElement::GDOMHTMLButtonElement(PassRefPtr<WebCore::HTMLButtonElement> impl)
    : GDOMHTMLElement(impl)
{
}

void
gdom_html_button_element_click (GdomHTMLButtonElement *thiz)
{
    g_return_if_fail (thiz);
    WebCore::HTMLButtonElement * item = (gdom_html_button_element_get_private(thiz));
    g_return_if_fail (item);
    item->click();

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLButtonElement.h"
#include <gdom/GdomHTMLButtonElement.h>
#include <gdom/PrivateGdomHTMLButtonElement.h>
#include <gdom/PrivateIntGdomHTMLButtonElement.h>
#include <gdom/GdomHTMLButtonElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLButtonElement, gdom_html_button_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLButtonElementPrivate {
    class WebCore::HTMLButtonElement *item;
};

#define GDOM_HTML_BUTTON_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_BUTTON_ELEMENT, GdomHTMLButtonElementPrivate))
*/
G_END_DECLS
WebCore::HTMLButtonElement *
gdom_html_button_element_get_private(GdomHTMLButtonElement *request)
{
    GDOMHTMLButtonElement *res;
    res = static_cast<GDOMHTMLButtonElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLButtonElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_FORM,
    PROP_ACCESS_KEY,
    PROP_DISABLED,
    PROP_AUTOFOCUS,
    PROP_NAME,
    PROP_TYPE,
    PROP_VALUE,
    PROP_WILL_VALIDATE,
};


static void gdom_html_button_element_finalize(GObject* object)
{
    /*GdomHTMLButtonElement* request = GDOM_HTML_BUTTON_ELEMENT(object);*/
    /*GdomHTMLButtonElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_button_element_parent_class)->finalize(object);
}

static void gdom_html_button_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLButtonElement *self = GDOM_HTML_BUTTON_ELEMENT(object);
    WebCore::HTMLButtonElement * gself = (gdom_html_button_element_get_private(self));
    switch (prop_id) {
     case PROP_ACCESS_KEY:
    {
         gself->setAccessKey(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_DISABLED:
    {
         gself->setDisabled((g_value_get_boolean (value)) );
         break;
    }
     case PROP_AUTOFOCUS:
    {
         gself->setAutofocus((g_value_get_boolean (value)) );
         break;
    }
     case PROP_NAME:
    {
         gself->setName(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_VALUE:
    {
         gself->setValue(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_button_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLButtonElement *self = GDOM_HTML_BUTTON_ELEMENT(object);
    WebCore::HTMLButtonElement * gself = (gdom_html_button_element_get_private(self));
    switch (prop_id) {
    case PROP_FORM:
    {
         PassRefPtr<WebCore::HTMLFormElement> ptr = gself->form();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_ACCESS_KEY:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->accessKey()));
         break;
    }
    case PROP_DISABLED:
    {
         g_value_set_boolean (value, gself->disabled());
         break;
    }
    case PROP_AUTOFOCUS:
    {
         g_value_set_boolean (value, gself->autofocus());
         break;
    }
    case PROP_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->name()));
         break;
    }
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    case PROP_VALUE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->value()));
         break;
    }
    case PROP_WILL_VALIDATE:
    {
         g_value_set_boolean (value, gself->willValidate());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_button_element_class_init(GdomHTMLButtonElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_button_element_finalize;
    g_klass->set_property = gdom_html_button_element__set_property_fn;
    g_klass->get_property = gdom_html_button_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_FORM,
            g_param_spec_object ("form", /* name */
                "html_button_element_form", /* short description */
                "read-only  GdomHTMLFormElement * HTMLButtonElement.form", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_FORM_ELEMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ACCESS_KEY,
            g_param_spec_string ("access_key", /* name */
                "html_button_element_access_key", /* short description */
                "read-write  gchar * HTMLButtonElement.access_key", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DISABLED,
            g_param_spec_boolean ("disabled", /* name */
                "html_button_element_disabled", /* short description */
                "read-write  gboolean HTMLButtonElement.disabled", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_AUTOFOCUS,
            g_param_spec_boolean ("autofocus", /* name */
                "html_button_element_autofocus", /* short description */
                "read-write  gboolean HTMLButtonElement.autofocus", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NAME,
            g_param_spec_string ("name", /* name */
                "html_button_element_name", /* short description */
                "read-write  gchar * HTMLButtonElement.name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "html_button_element_type", /* short description */
                "read-only  gchar * HTMLButtonElement.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_VALUE,
            g_param_spec_string ("value", /* name */
                "html_button_element_value", /* short description */
                "read-write  gchar * HTMLButtonElement.value", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_WILL_VALIDATE,
            g_param_spec_boolean ("will_validate", /* name */
                "html_button_element_will_validate", /* short description */
                "read-only  gboolean HTMLButtonElement.will_validate", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLButtonElementPrivate));*/
}

static void gdom_html_button_element_init(GdomHTMLButtonElement* request)
{
    /*GdomHTMLButtonElementPrivate* priv = GDOM_HTML_BUTTON_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

